export_GPS_fasta: Subsets a given fasta file by given proteins for GPS 5.0 PTM...

View source: R/export_GPS_fasta.R

export_GPS_fastaR Documentation

Subsets a given fasta file by given proteins for GPS 5.0 PTM site prediction

Description

Subsets a given fasta file by given proteins for GPS 5.0 PTM site prediction

Usage

export_GPS_fasta(proteins, fasta.file, output.dir = "Data/GPS")

Arguments

proteins

vector of proteins to export

fasta.file

path to fasta file containing all sequences

output.dir

path to folder where fasta file should be saved


nicohuttmann/ptmOmics documentation built on Nov. 9, 2022, 4:01 a.m.