View source: R/export_GPS_fasta.R
| export_GPS_fasta | R Documentation |
Subsets a given fasta file by given proteins for GPS 5.0 PTM site prediction
export_GPS_fasta(proteins, fasta.file, output.dir = "Data/GPS")
proteins |
vector of proteins to export |
fasta.file |
path to fasta file containing all sequences |
output.dir |
path to folder where fasta file should be saved |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.